You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ode.apache.org by mr...@apache.org on 2006/07/27 23:52:07 UTC

svn commit: r426260 [6/23] - in /incubator/ode/scratch/pxe-iapi: ./ axis2-examples/src/examples/DynPartner/ axis2-examples/src/examples/HelloWorld2/ axis2-examples/src/examples/MagicSession/ axis2-war/ axis2-war/src/main/webapp/WEB-INF/ axis2-war/src/m...

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/BpelCompiler11.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/BpelCompiler11.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/BpelCompiler11.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/BpelCompiler11.java Thu Jul 27 14:51:14 2006
@@ -3,12 +3,12 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.*;
-import com.fs.pxe.bom.wsdl.WSDLFactory4BPEL;
-import com.fs.pxe.bom.wsdl.WSDLFactoryBPEL11;
-import com.fs.pxe.bpel.elang.xpath10.compiler.XPath10ExpressionCompilerBPEL11;
+import org.apache.ode.bom.api.*;
+import org.apache.ode.bom.wsdl.WSDLFactory4BPEL;
+import org.apache.ode.bom.wsdl.WSDLFactoryBPEL11;
+import org.apache.ode.bpel.elang.xpath10.compiler.XPath10ExpressionCompilerBPEL11;
 
 /**
  * BPEL v1.1 compiler.

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/BpelCompiler20.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/BpelCompiler20.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/BpelCompiler20.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/BpelCompiler20.java Thu Jul 27 14:51:14 2006
@@ -3,13 +3,13 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.*;
-import com.fs.pxe.bom.wsdl.WSDLFactory4BPEL;
-import com.fs.pxe.bom.wsdl.WSDLFactoryBPEL20;
-import com.fs.pxe.bpel.elang.xpath10.compiler.XPath10ExpressionCompilerBPEL20;
-import com.fs.pxe.bpel.elang.xpath20.compiler.XPath20ExpressionCompilerBPEL20;
+import org.apache.ode.bom.api.*;
+import org.apache.ode.bom.wsdl.WSDLFactory4BPEL;
+import org.apache.ode.bom.wsdl.WSDLFactoryBPEL20;
+import org.apache.ode.bpel.elang.xpath10.compiler.XPath10ExpressionCompilerBPEL20;
+import org.apache.ode.bpel.elang.xpath20.compiler.XPath20ExpressionCompilerBPEL20;
 
 /**
  * OASIS BPEL V2.0 Compiler

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/CommonCompilationMessages.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/CommonCompilationMessages.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/CommonCompilationMessages.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/CommonCompilationMessages.java Thu Jul 27 14:51:14 2006
@@ -4,10 +4,10 @@
  *
  */
 
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bpel.capi.CompilationMessage;
-import com.fs.pxe.bpel.capi.CompilationMessageBundle;
+import org.apache.ode.bpel.capi.CompilationMessage;
+import org.apache.ode.bpel.capi.CompilationMessageBundle;
 
 import javax.wsdl.PortType;
 import javax.xml.namespace.QName;

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/CompensateGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/CompensateGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/CompensateGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/CompensateGenerator.java Thu Jul 27 14:51:14 2006
@@ -3,12 +3,12 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bom.api.CompensateActivity;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OCompensate;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bom.api.CompensateActivity;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OCompensate;
 
 
 /**

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/DefaultActivityGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/DefaultActivityGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/DefaultActivityGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/DefaultActivityGenerator.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bpel.capi.CompilerContext;
+import org.apache.ode.bpel.capi.CompilerContext;
 
 /**
  * Base implementation of the {@link ActivityGenerator} interface.

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/DefaultWsdlFinder.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/DefaultWsdlFinder.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/DefaultWsdlFinder.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/DefaultWsdlFinder.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.wsdl.Definition4BPEL;
+import org.apache.ode.bom.wsdl.Definition4BPEL;
 
 import java.io.IOException;
 import java.io.InputStream;

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/DefaultXsltFinder.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/DefaultXsltFinder.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/DefaultXsltFinder.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/DefaultXsltFinder.java Thu Jul 27 14:51:14 2006
@@ -1,6 +1,6 @@
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.utils.StreamUtils;
+import org.apache.ode.utils.StreamUtils;
 import java.net.URI;
 import java.io.IOException;
 import java.io.File;

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/EmptyGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/EmptyGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/EmptyGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/EmptyGenerator.java Thu Jul 27 14:51:14 2006
@@ -3,11 +3,11 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OEmpty;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OEmpty;
 
 
 /**

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/FlowGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/FlowGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/FlowGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/FlowGenerator.java Thu Jul 27 14:51:14 2006
@@ -3,19 +3,19 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bom.api.CompositeActivity;
-import com.fs.pxe.bom.api.FlowActivity;
-import com.fs.pxe.bom.api.Link;
-import com.fs.pxe.bpel.capi.CompilationException;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OFlow;
-import com.fs.pxe.bpel.o.OLink;
-import com.fs.utils.msg.MessageBundle;
-import com.fs.utils.stl.CollectionsX;
-import com.fs.utils.stl.MemberOfFunction;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bom.api.CompositeActivity;
+import org.apache.ode.bom.api.FlowActivity;
+import org.apache.ode.bom.api.Link;
+import org.apache.ode.bpel.capi.CompilationException;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OFlow;
+import org.apache.ode.bpel.o.OLink;
+import org.apache.ode.utils.msg.MessageBundle;
+import org.apache.ode.utils.stl.CollectionsX;
+import org.apache.ode.utils.stl.MemberOfFunction;
 
 import java.util.Iterator;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/FlowGeneratorMessages.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/FlowGeneratorMessages.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/FlowGeneratorMessages.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/FlowGeneratorMessages.java Thu Jul 27 14:51:14 2006
@@ -4,10 +4,10 @@
  *
  */
 
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bpel.capi.CompilationMessage;
-import com.fs.pxe.bpel.capi.CompilationMessageBundle;
+import org.apache.ode.bpel.capi.CompilationMessage;
+import org.apache.ode.bpel.capi.CompilationMessageBundle;
 
 public class FlowGeneratorMessages extends CompilationMessageBundle {
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ForEachGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ForEachGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ForEachGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ForEachGenerator.java Thu Jul 27 14:51:14 2006
@@ -1,14 +1,14 @@
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bom.api.Constants;
-import com.fs.pxe.bom.api.ForEachActivity;
-import com.fs.pxe.bom.impl.nodes.VariableImpl;
-import com.fs.pxe.bpel.capi.CompilationException;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OForEach;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.utils.msg.MessageBundle;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bom.api.Constants;
+import org.apache.ode.bom.api.ForEachActivity;
+import org.apache.ode.bom.impl.nodes.VariableImpl;
+import org.apache.ode.bpel.capi.CompilationException;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OForEach;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.utils.msg.MessageBundle;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ForEachGeneratorMessages.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ForEachGeneratorMessages.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ForEachGeneratorMessages.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ForEachGeneratorMessages.java Thu Jul 27 14:51:14 2006
@@ -1,7 +1,7 @@
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bpel.capi.CompilationMessage;
-import com.fs.pxe.bpel.capi.CompilationMessageBundle;
+import org.apache.ode.bpel.capi.CompilationMessage;
+import org.apache.ode.bpel.capi.CompilationMessageBundle;
 
 public class ForEachGeneratorMessages extends CompilationMessageBundle {
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/InvokeGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/InvokeGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/InvokeGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/InvokeGenerator.java Thu Jul 27 14:51:14 2006
@@ -4,18 +4,18 @@
  *
  */
 
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bom.api.Constants;
-import com.fs.pxe.bom.api.Correlation;
-import com.fs.pxe.bom.api.InvokeActivity;
-import com.fs.pxe.bpel.capi.CompilationException;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OInvoke;
-import com.fs.pxe.bpel.o.OProcess;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.utils.msg.MessageBundle;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bom.api.Constants;
+import org.apache.ode.bom.api.Correlation;
+import org.apache.ode.bom.api.InvokeActivity;
+import org.apache.ode.bpel.capi.CompilationException;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OInvoke;
+import org.apache.ode.bpel.o.OProcess;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.utils.msg.MessageBundle;
 
 import java.util.Collection;
 import java.util.List;

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/InvokeGeneratorMessages.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/InvokeGeneratorMessages.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/InvokeGeneratorMessages.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/InvokeGeneratorMessages.java Thu Jul 27 14:51:14 2006
@@ -4,10 +4,10 @@
  *
  */
 
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bpel.capi.CompilationMessage;
-import com.fs.pxe.bpel.capi.CompilationMessageBundle;
+import org.apache.ode.bpel.capi.CompilationMessage;
+import org.apache.ode.bpel.capi.CompilationMessageBundle;
 
 public class InvokeGeneratorMessages extends CompilationMessageBundle {
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/PickGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/PickGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/PickGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/PickGenerator.java Thu Jul 27 14:51:14 2006
@@ -3,12 +3,12 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.*;
-import com.fs.pxe.bpel.capi.CompilationException;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OPickReceive;
+import org.apache.ode.bom.api.*;
+import org.apache.ode.bpel.capi.CompilationException;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OPickReceive;
 
 import java.util.Iterator;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/PickGeneratorMessages.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/PickGeneratorMessages.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/PickGeneratorMessages.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/PickGeneratorMessages.java Thu Jul 27 14:51:14 2006
@@ -4,10 +4,10 @@
  *
  */
 
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bpel.capi.CompilationMessage;
-import com.fs.pxe.bpel.capi.CompilationMessageBundle;
+import org.apache.ode.bpel.capi.CompilationMessage;
+import org.apache.ode.bpel.capi.CompilationMessageBundle;
 
 public class PickGeneratorMessages extends CompilationMessageBundle {
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/PickReceiveGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/PickReceiveGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/PickReceiveGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/PickReceiveGenerator.java Thu Jul 27 14:51:14 2006
@@ -3,23 +3,23 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bom.api.Correlation;
-import com.fs.pxe.bpel.capi.CompilationException;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OPickReceive;
-import com.fs.pxe.bpel.o.OProcess;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.utils.msg.MessageBundle;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bom.api.Correlation;
+import org.apache.ode.bpel.capi.CompilationException;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OPickReceive;
+import org.apache.ode.bpel.o.OProcess;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.utils.msg.MessageBundle;
 
 import javax.xml.namespace.QName;
 import java.util.Collection;
 
 /**
  * Base class for the {@link PickGenerator} and {@link ReceiveGenerator} classes.
- * Provides common functionality related to generating {@link com.fs.pxe.bpel.o.OPickReceive.OnMessage}
+ * Provides common functionality related to generating {@link org.apache.ode.bpel.o.OPickReceive.OnMessage}
  * objects.
  */
 abstract class PickReceiveGenerator extends DefaultActivityGenerator {

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ReceiveGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ReceiveGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ReceiveGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ReceiveGenerator.java Thu Jul 27 14:51:14 2006
@@ -3,13 +3,13 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bom.api.ReceiveActivity;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OEmpty;
-import com.fs.pxe.bpel.o.OPickReceive;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bom.api.ReceiveActivity;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OEmpty;
+import org.apache.ode.bpel.o.OPickReceive;
 
 class ReceiveGenerator extends PickReceiveGenerator {
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ReplyGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ReplyGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ReplyGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ReplyGenerator.java Thu Jul 27 14:51:14 2006
@@ -3,13 +3,13 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bom.api.Correlation;
-import com.fs.pxe.bpel.capi.CompilationException;
-import com.fs.pxe.bpel.o.*;
-import com.fs.utils.msg.MessageBundle;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bom.api.Correlation;
+import org.apache.ode.bpel.capi.CompilationException;
+import org.apache.ode.bpel.o.*;
+import org.apache.ode.utils.msg.MessageBundle;
 
 import java.util.Iterator;
 
@@ -30,7 +30,7 @@
   }
 
   public void compile(OActivity output, Activity src) {
-    com.fs.pxe.bom.api.ReplyActivity replyDef = (com.fs.pxe.bom.api.ReplyActivity) src;
+    org.apache.ode.bom.api.ReplyActivity replyDef = (org.apache.ode.bom.api.ReplyActivity) src;
     OReply oreply = (OReply) output;
 
     oreply.isFaultReply = replyDef.getFaultName() != null;

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ReplyGeneratorMessages.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ReplyGeneratorMessages.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ReplyGeneratorMessages.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ReplyGeneratorMessages.java Thu Jul 27 14:51:14 2006
@@ -4,10 +4,10 @@
  *
  */
 
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bpel.capi.CompilationMessage;
-import com.fs.pxe.bpel.capi.CompilationMessageBundle;
+import org.apache.ode.bpel.capi.CompilationMessage;
+import org.apache.ode.bpel.capi.CompilationMessageBundle;
 
 public class ReplyGeneratorMessages extends CompilationMessageBundle {
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/RethrowGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/RethrowGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/RethrowGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/RethrowGenerator.java Thu Jul 27 14:51:14 2006
@@ -3,11 +3,11 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.ORethrow;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.ORethrow;
 
 class RethrowGenerator extends DefaultActivityGenerator {
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/SequenceGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/SequenceGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/SequenceGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/SequenceGenerator.java Thu Jul 27 14:51:14 2006
@@ -3,14 +3,14 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bom.api.CompositeActivity;
-import com.fs.pxe.bom.api.SequenceActivity;
-import com.fs.pxe.bpel.capi.CompilationException;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OSequence;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bom.api.CompositeActivity;
+import org.apache.ode.bom.api.SequenceActivity;
+import org.apache.ode.bpel.capi.CompilationException;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OSequence;
 
 import java.util.Iterator;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/SwitchGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/SwitchGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/SwitchGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/SwitchGenerator.java Thu Jul 27 14:51:14 2006
@@ -6,12 +6,12 @@
 
 
 
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bom.api.SwitchActivity;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OSwitch;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bom.api.SwitchActivity;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OSwitch;
 
 import java.util.Iterator;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/TerminateGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/TerminateGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/TerminateGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/TerminateGenerator.java Thu Jul 27 14:51:14 2006
@@ -3,11 +3,11 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OTerminate;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OTerminate;
 
 
 /**

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ThrowGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ThrowGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ThrowGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/ThrowGenerator.java Thu Jul 27 14:51:14 2006
@@ -3,12 +3,12 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bom.api.ThrowActivity;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OThrow;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bom.api.ThrowActivity;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OThrow;
 
 
 /**

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WSDLRegistry.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WSDLRegistry.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WSDLRegistry.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WSDLRegistry.java Thu Jul 27 14:51:14 2006
@@ -3,16 +3,16 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.wsdl.*;
-import com.fs.pxe.bpel.capi.CompilationException;
-import com.fs.pxe.bpel.capi.CompilerContext;
-import com.fs.utils.msg.MessageBundle;
-import com.fs.utils.xsd.SchemaModel;
-import com.fs.utils.xsd.SchemaModelImpl;
-import com.fs.utils.xsd.XSUtils;
-import com.fs.utils.xsd.XsdException;
+import org.apache.ode.bom.wsdl.*;
+import org.apache.ode.bpel.capi.CompilationException;
+import org.apache.ode.bpel.capi.CompilerContext;
+import org.apache.ode.utils.msg.MessageBundle;
+import org.apache.ode.utils.xsd.SchemaModel;
+import org.apache.ode.utils.xsd.SchemaModelImpl;
+import org.apache.ode.utils.xsd.XSUtils;
+import org.apache.ode.utils.xsd.XsdException;
 import com.sun.org.apache.xerces.internal.xni.parser.XMLEntityResolver;
 
 import java.net.URI;

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WaitGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WaitGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WaitGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WaitGenerator.java Thu Jul 27 14:51:14 2006
@@ -4,14 +4,14 @@
  *
  */
 
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bom.api.WaitActivity;
-import com.fs.pxe.bpel.capi.CompilationException;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OWait;
-import com.fs.utils.msg.MessageBundle;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bom.api.WaitActivity;
+import org.apache.ode.bpel.capi.CompilationException;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OWait;
+import org.apache.ode.utils.msg.MessageBundle;
 
 /**
  * Generates code for the <code>&lt;wait&gt;</code> activities.

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WaitGeneratorMessages.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WaitGeneratorMessages.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WaitGeneratorMessages.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WaitGeneratorMessages.java Thu Jul 27 14:51:14 2006
@@ -4,10 +4,10 @@
  *
  */
 
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bpel.capi.CompilationMessage;
-import com.fs.pxe.bpel.capi.CompilationMessageBundle;
+import org.apache.ode.bpel.capi.CompilationMessage;
+import org.apache.ode.bpel.capi.CompilationMessageBundle;
 
 public class WaitGeneratorMessages extends CompilationMessageBundle {
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WhileGenerator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WhileGenerator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WhileGenerator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WhileGenerator.java Thu Jul 27 14:51:14 2006
@@ -3,12 +3,12 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.api.Activity;
-import com.fs.pxe.bom.api.WhileActivity;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OWhile;
+import org.apache.ode.bom.api.Activity;
+import org.apache.ode.bom.api.WhileActivity;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OWhile;
 
 
 /**

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WsdlFinder.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WsdlFinder.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WsdlFinder.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WsdlFinder.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.wsdl.Definition4BPEL;
+import org.apache.ode.bom.wsdl.Definition4BPEL;
 
 import java.io.IOException;
 import java.io.InputStream;

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WsdlFinderXMLEntityResolver.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WsdlFinderXMLEntityResolver.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WsdlFinderXMLEntityResolver.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/WsdlFinderXMLEntityResolver.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
 import java.io.IOException;
 import java.net.URI;

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/XsltFinder.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/XsltFinder.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/XsltFinder.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/XsltFinder.java Thu Jul 27 14:51:14 2006
@@ -1,4 +1,4 @@
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
 import java.net.URI;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/package.html
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/package.html?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/package.html (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/package.html Thu Jul 27 14:51:14 2006
@@ -2,7 +2,7 @@
   <body>
     <p>BPEL compiler (bpelc) classes and interfaces.
     Taking as input the de-referenced BPEL object model
-    (see {@link com.fs.pxe.bom.impl.nodes}), the BPEL compiler applies
+    (see {@link org.apache.ode.bom.impl.nodes}), the BPEL compiler applies
     static analysis rules to ensure compliance of the BPEL model.
     Upon successful analysis, the compiler generates a 
     &quot;compiled&quot; process description suitable for

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/StaticCheckSuite.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/StaticCheckSuite.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/StaticCheckSuite.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/StaticCheckSuite.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
 import junit.framework.Test;
 import junit.framework.TestSuite;

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/StaticCheckTCase.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/StaticCheckTCase.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/WSDLRegistryTest.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/WSDLRegistryTest.java Thu Jul 27 14:51:14 2006
@@ -3,12 +3,12 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.wsdl.Definition4BPEL;
-import com.fs.pxe.bom.wsdl.WSDLFactory4BPEL;
-import com.fs.pxe.bom.wsdl.WSDLFactoryBPEL11;
-import com.fs.utils.xsd.SchemaModel;
+import org.apache.ode.bom.wsdl.Definition4BPEL;
+import org.apache.ode.bom.wsdl.WSDLFactory4BPEL;
+import org.apache.ode.bom.wsdl.WSDLFactoryBPEL11;
+import org.apache.ode.utils.xsd.SchemaModel;
 
 import java.net.URL;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler_2_0/GoodCompileSuite.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler_2_0/GoodCompileSuite.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler_2_0/GoodCompileSuite.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler_2_0/GoodCompileSuite.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler_2_0;
+package org.apache.ode.bpel.compiler_2_0;
 
 import junit.framework.Test;
 import junit.framework.TestSuite;

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler_2_0/GoodCompileTCase.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler_2_0/GoodCompileTCase.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/BpelParseErr.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/BpelParseErr.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions
-    targetNamespace="http://pxe/test/compile.wsdl"
+    targetNamespace="http://ode/test/compile.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/test/compile.wsdl"
+    xmlns:tns="http://ode/test/compile.wsdl"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/"
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/CompensateNAtoContext.bpel
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/CompensateNAtoContext.bpel?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/CompensateNAtoContext.bpel (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/CompensateNAtoContext.bpel Thu Jul 27 14:51:14 2006
@@ -2,7 +2,7 @@
     suppressJoinFailure="yes" targetNamespace="http://jlo/test/compile"
     xmlns="http://schemas.xmlsoap.org/ws/2003/03/business-process/"
     xmlns:bpws="http://schemas.xmlsoap.org/ws/2003/03/business-process/"
-    xmlns:tns="http://pxe/test/compile"
+    xmlns:tns="http://ode/test/compile"
     xmlns:xsd="http://www.w3.org/2001/XMLSchema">
     <variables>
         <variable name="var1" 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/CompensateNAtoContext.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/CompensateNAtoContext.wsdl?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/CompensateNAtoContext.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/CompensateNAtoContext.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/test/compile.wsdl"
+    targetNamespace="http://ode/test/compile.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/test/compile.wsdl"
+    xmlns:tns="http://ode/test/compile.wsdl"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateLinkDecl.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateLinkDecl.wsdl?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateLinkDecl.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateLinkDecl.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/test/compile.wsdl"
+    targetNamespace="http://ode/test/compile.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/test/compile.wsdl"
+    xmlns:tns="http://ode/test/compile.wsdl"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateLinkSource.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateLinkSource.wsdl?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateLinkSource.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateLinkSource.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/test/compile.wsdl"
+    targetNamespace="http://ode/test/compile.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/test/compile.wsdl"
+    xmlns:tns="http://ode/test/compile.wsdl"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateLinkTarget.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateLinkTarget.wsdl?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateLinkTarget.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateLinkTarget.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/test/compile.wsdl"
+    targetNamespace="http://ode/test/compile.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/test/compile.wsdl"
+    xmlns:tns="http://ode/test/compile.wsdl"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateVariableDecl.bpel
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateVariableDecl.bpel?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateVariableDecl.bpel (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateVariableDecl.bpel Thu Jul 27 14:51:14 2006
@@ -2,7 +2,7 @@
     suppressJoinFailure="yes" targetNamespace="http://jlo/test/compile"
     xmlns="http://schemas.xmlsoap.org/ws/2003/03/business-process/"
     xmlns:bpws="http://schemas.xmlsoap.org/ws/2003/03/business-process/"
-    xmlns:tns="http://pxe/test/compile"
+    xmlns:tns="http://ode/test/compile"
     xmlns:xsd="http://www.w3.org/2001/XMLSchema">
     <variables>
         <variable name="var1" 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateVariableDecl.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateVariableDecl.wsdl?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateVariableDecl.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/DuplicateVariableDecl.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/test/compile.wsdl"
+    targetNamespace="http://ode/test/compile.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/test/compile.wsdl"
+    xmlns:tns="http://ode/test/compile.wsdl"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/LinkMissingSourceActivity.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/LinkMissingSourceActivity.wsdl?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/LinkMissingSourceActivity.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/LinkMissingSourceActivity.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/test/compile.wsdl"
+    targetNamespace="http://ode/test/compile.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/test/compile.wsdl"
+    xmlns:tns="http://ode/test/compile.wsdl"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/LinkMissingTargetActivity.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/LinkMissingTargetActivity.wsdl?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/LinkMissingTargetActivity.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/LinkMissingTargetActivity.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/test/compile.wsdl"
+    targetNamespace="http://ode/test/compile.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/test/compile.wsdl"
+    xmlns:tns="http://ode/test/compile.wsdl"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/PortTypeMismatch.bpel
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/PortTypeMismatch.bpel?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/PortTypeMismatch.bpel (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/PortTypeMismatch.bpel Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <process name="InvalidBpelFunction" suppressJoinFailure="yes" targetNamespace="http://jlo/test/compile"
     xmlns="http://schemas.xmlsoap.org/ws/2003/03/business-process/"
     xmlns:bpws="http://schemas.xmlsoap.org/ws/2003/03/business-process/"
-    xmlns:tns="http://pxe/test/compile"
+    xmlns:tns="http://ode/test/compile"
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"
-    xmlns:test="http://pxe/test/compile.wsdl">
+    xmlns:test="http://ode/test/compile.wsdl">
     
     <partnerLinks>
         <partnerLink name="testPartnerLink" 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/PortTypeMismatch.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/PortTypeMismatch.wsdl?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/PortTypeMismatch.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/PortTypeMismatch.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/test/compile.wsdl"
+    targetNamespace="http://ode/test/compile.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/test/compile.wsdl"
+    xmlns:tns="http://ode/test/compile.wsdl"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UndeclaredPropertyAlias.bpel
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UndeclaredPropertyAlias.bpel?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UndeclaredPropertyAlias.bpel (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UndeclaredPropertyAlias.bpel Thu Jul 27 14:51:14 2006
@@ -1,11 +1,11 @@
 <process 
     name="InvalidBpelFunction" suppressJoinFailure="yes" 
-    targetNamespace="http://pxe/test/compile"
+    targetNamespace="http://ode/test/compile"
     xmlns="http://schemas.xmlsoap.org/ws/2003/03/business-process/"
     xmlns:bpws="http://schemas.xmlsoap.org/ws/2003/03/business-process/"
-    xmlns:tns="http://pxe/test/compile"
+    xmlns:tns="http://ode/test/compile"
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"
-    xmlns:test="http://pxe/test/compile.wsdl">
+    xmlns:test="http://ode/test/compile.wsdl">
     <variables>
         <variable name="var1" 
             messageType="test:TestMessage" />

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UndeclaredPropertyAlias.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UndeclaredPropertyAlias.wsdl?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UndeclaredPropertyAlias.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UndeclaredPropertyAlias.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/test/compile.wsdl"
+    targetNamespace="http://ode/test/compile.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/test/compile.wsdl"
+    xmlns:tns="http://ode/test/compile.wsdl"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UndeclaredVariable.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UndeclaredVariable.wsdl?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UndeclaredVariable.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UndeclaredVariable.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/test/compile.wsdl"
+    targetNamespace="http://ode/test/compile.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/test/compile.wsdl"
+    xmlns:tns="http://ode/test/compile.wsdl"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UnknownBpelFunction.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UnknownBpelFunction.wsdl?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UnknownBpelFunction.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/UnknownBpelFunction.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/test/compile.wsdl"
+    targetNamespace="http://ode/test/compile.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/test/compile.wsdl"
+    xmlns:tns="http://ode/test/compile.wsdl"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"

Modified: incubator/ode/scratch/pxe-iapi/bpel-connector/.classpath
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-connector/.classpath?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-connector/.classpath (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-connector/.classpath Thu Jul 27 14:51:14 2006
@@ -2,8 +2,8 @@
 <classpath>
 	<classpathentry kind="src" path="src/main/java"/>
 	<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
-	<classpathentry combineaccessrules="false" kind="src" path="/pxe-jca-ra"/>
-	<classpathentry combineaccessrules="false" kind="src" path="/pxe-jca-server"/>
-	<classpathentry combineaccessrules="false" kind="src" path="/pxe-bpel-api"/>
+	<classpathentry combineaccessrules="false" kind="src" path="/ode-jca-ra"/>
+	<classpathentry combineaccessrules="false" kind="src" path="/ode-jca-server"/>
+	<classpathentry combineaccessrules="false" kind="src" path="/ode-bpel-api"/>
 	<classpathentry kind="output" path="target/classes"/>
 </classpath>

Modified: incubator/ode/scratch/pxe-iapi/bpel-connector/.project
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-connector/.project?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-connector/.project (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-connector/.project Thu Jul 27 14:51:14 2006
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <projectDescription>
-	<name>pxe-bpel-connector</name>
+	<name>ode-bpel-connector</name>
 	<comment></comment>
 	<projects>
 	</projects>

Modified: incubator/ode/scratch/pxe-iapi/bpel-connector/pom.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-connector/pom.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-connector/pom.xml (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-connector/pom.xml Thu Jul 27 14:51:14 2006
@@ -1,28 +1,28 @@
 <project>
-    <artifactId>pxe-bpel-connector</artifactId>
-    <name>PXE :: BPEL Connector </name>
+    <artifactId>ode-bpel-connector</artifactId>
+    <name>ODE :: BPEL Connector </name>
     <description>Implementation of a the BPEL JCA connector.</description>
 
     <modelVersion>4.0.0</modelVersion>
     <parent>
-        <groupId>pxe</groupId>
-        <artifactId>pxe</artifactId>
+        <groupId>ode</groupId>
+        <artifactId>ode</artifactId>
         <version>2.0-SNAPSHOT</version>
     </parent>
-    <groupId>pxe</groupId>
+    <groupId>ode</groupId>
     <version>2.0-SNAPSHOT</version>
     <dependencies>
         <dependency>
-            <groupId>pxe</groupId>
-            <artifactId>pxe-bpel-api-jca</artifactId>
+            <groupId>ode</groupId>
+            <artifactId>ode-bpel-api-jca</artifactId>
         </dependency>
         <dependency>
-            <groupId>pxe</groupId>
-            <artifactId>pxe-jca-ra</artifactId>
+            <groupId>ode</groupId>
+            <artifactId>ode-jca-ra</artifactId>
         </dependency>
         <dependency>
-            <groupId>pxe</groupId>
-            <artifactId>pxe-jca-server</artifactId>
+            <groupId>ode</groupId>
+            <artifactId>ode-jca-server</artifactId>
         </dependency>
     </dependencies>
 </project>

Modified: incubator/ode/scratch/pxe-iapi/bpel-connector/src/main/java/org/apache/ode/bpel/connector/BpelServerConnector.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-connector/src/main/java/org/apache/ode/bpel/connector/BpelServerConnector.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-connector/src/main/java/org/apache/ode/bpel/connector/BpelServerConnector.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-connector/src/main/java/org/apache/ode/bpel/connector/BpelServerConnector.java Thu Jul 27 14:51:14 2006
@@ -1,7 +1,7 @@
-package com.fs.pxe.bpel.connector;
+package org.apache.ode.bpel.connector;
 
-import com.fs.pxe.bpel.iapi.BpelServer;
-import com.fs.pxe.jca.server.rmi.RmiTransportServerImpl;
+import org.apache.ode.bpel.iapi.BpelServer;
+import org.apache.ode.jca.server.rmi.RmiTransportServerImpl;
 
 public class BpelServerConnector {
 
@@ -10,7 +10,7 @@
   
   public BpelServerConnector() {
     _transport = new RmiTransportServerImpl();
-    _transport.setId("pxe/BpelEngine");
+    _transport.setId("ode/BpelEngine");
   }
   
   public void setBpelServer(BpelServer server) {

Modified: incubator/ode/scratch/pxe-iapi/bpel-connector/src/main/java/org/apache/ode/bpel/connector/ConnectionProviderImpl.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-connector/src/main/java/org/apache/ode/bpel/connector/ConnectionProviderImpl.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-connector/src/main/java/org/apache/ode/bpel/connector/ConnectionProviderImpl.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-connector/src/main/java/org/apache/ode/bpel/connector/ConnectionProviderImpl.java Thu Jul 27 14:51:14 2006
@@ -1,12 +1,12 @@
-package com.fs.pxe.bpel.connector;
+package org.apache.ode.bpel.connector;
 
-import com.fs.pxe.bpel.iapi.BpelServer;
-import com.fs.pxe.bpel.pmapi.BpelManagementFacade;
-import com.fs.pxe.jca.server.ConnectionProvider;
+import org.apache.ode.bpel.iapi.BpelServer;
+import org.apache.ode.bpel.pmapi.BpelManagementFacade;
+import org.apache.ode.jca.server.ConnectionProvider;
 
 /**
- * Implementation of the {@link com.fs.pxe.jca.server.ConnectionProvider}
- * interface: provides {@link com.fs.pxe.bpel.pmapi.BpelManagementFacade}
+ * Implementation of the {@link org.apache.ode.jca.server.ConnectionProvider}
+ * interface: provides {@link org.apache.ode.bpel.pmapi.BpelManagementFacade}
  * objects. 
  */
 class ConnectionProviderImpl implements ConnectionProvider {
@@ -18,7 +18,7 @@
   }
   
   public String [] getConnectionIntefaces() {
-    return new String[] { "com.fs.pxe.bpel.jca.clientapi.ProcessManagementConnection" };
+    return new String[] { "org.apache.ode.bpel.jca.clientapi.ProcessManagementConnection" };
   }
 
   public Object createConnectionObject() {

Modified: incubator/ode/scratch/pxe-iapi/bpel-dd/pom.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-dd/pom.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-dd/pom.xml (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-dd/pom.xml Thu Jul 27 14:51:14 2006
@@ -1,26 +1,26 @@
 <?xml version="1.0"?>
 <project>
-  <groupId>pxe</groupId>
-  <artifactId>pxe-bpel-dd</artifactId>
-  <name>PXE :: BPEL Deployment Descriptor</name>
+  <groupId>ode</groupId>
+  <artifactId>ode-bpel-dd</artifactId>
+  <name>ODE :: BPEL Deployment Descriptor</name>
   <description>Contains the deployment descriptor classes used to validate the descriptor during compilation and read it on deployment.</description>
 
   <modelVersion>4.0.0</modelVersion>
   <parent>
-    <groupId>pxe</groupId>
-    <artifactId>pxe</artifactId>
+    <groupId>ode</groupId>
+    <artifactId>ode</artifactId>
     <version>2.0-SNAPSHOT</version>
   </parent>
   <version>2.0-SNAPSHOT</version>
 
   <dependencies>
     <dependency>
-      <groupId>pxe</groupId>
-      <artifactId>pxe-bpel-obj</artifactId>
+      <groupId>ode</groupId>
+      <artifactId>ode-bpel-obj</artifactId>
     </dependency>
     <dependency>
-      <groupId>pxe</groupId>
-      <artifactId>pxe-utils</artifactId>
+      <groupId>ode</groupId>
+      <artifactId>ode-utils</artifactId>
     </dependency>
 
     <dependency>

Modified: incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDEnhancer.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDEnhancer.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDEnhancer.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDEnhancer.java Thu Jul 27 14:51:14 2006
@@ -1,6 +1,6 @@
-package com.fs.pxe.bpel.dd;
+package org.apache.ode.bpel.dd;
 
-import com.fs.pxe.bpel.o.OProcess;
+import org.apache.ode.bpel.o.OProcess;
 
 import javax.wsdl.Definition;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDException.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDException.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDException.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDException.java Thu Jul 27 14:51:14 2006
@@ -1,4 +1,4 @@
-package com.fs.pxe.bpel.dd;
+package org.apache.ode.bpel.dd;
 
 /**
  * Thrown when a deployment descriptor can't be processed properly.

Modified: incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDHandler.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDHandler.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDHandler.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDHandler.java Thu Jul 27 14:51:14 2006
@@ -1,6 +1,6 @@
-package com.fs.pxe.bpel.dd;
+package org.apache.ode.bpel.dd;
 
-import com.fs.pxe.bpel.o.OProcess;
+import org.apache.ode.bpel.o.OProcess;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.xmlbeans.XmlOptions;

Modified: incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDValidationException.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDValidationException.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDValidationException.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDValidationException.java Thu Jul 27 14:51:14 2006
@@ -1,4 +1,4 @@
-package com.fs.pxe.bpel.dd;
+package org.apache.ode.bpel.dd;
 
 /**
  * Thrown when the deployment descriptor can't be validated.

Modified: incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDValidator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDValidator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDValidator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/DDValidator.java Thu Jul 27 14:51:14 2006
@@ -1,6 +1,6 @@
-package com.fs.pxe.bpel.dd;
+package org.apache.ode.bpel.dd;
 
-import com.fs.pxe.bpel.o.OProcess;
+import org.apache.ode.bpel.o.OProcess;
 
 /**
  * Validates a specific part of a deployment descriptor.

Modified: incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/EndpointEnhancer.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/EndpointEnhancer.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/EndpointEnhancer.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/EndpointEnhancer.java Thu Jul 27 14:51:14 2006
@@ -1,7 +1,7 @@
-package com.fs.pxe.bpel.dd;
+package org.apache.ode.bpel.dd;
 
-import com.fs.pxe.bpel.o.OPartnerLink;
-import com.fs.pxe.bpel.o.OProcess;
+import org.apache.ode.bpel.o.OPartnerLink;
+import org.apache.ode.bpel.o.OProcess;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.w3c.dom.Element;

Modified: incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/EndpointValidator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/EndpointValidator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/EndpointValidator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/EndpointValidator.java Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
-package com.fs.pxe.bpel.dd;
+package org.apache.ode.bpel.dd;
 
-import com.fs.pxe.bpel.o.OPartnerLink;
-import com.fs.pxe.bpel.o.OProcess;
-import com.fs.utils.DOMUtils;
-import com.fs.utils.Namespaces;
+import org.apache.ode.bpel.o.OPartnerLink;
+import org.apache.ode.bpel.o.OProcess;
+import org.apache.ode.utils.DOMUtils;
+import org.apache.ode.utils.Namespaces;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;

Modified: incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/EventFilterValidator.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/EventFilterValidator.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/EventFilterValidator.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/java/org/apache/ode/bpel/dd/EventFilterValidator.java Thu Jul 27 14:51:14 2006
@@ -1,8 +1,8 @@
-package com.fs.pxe.bpel.dd;
+package org.apache.ode.bpel.dd;
 
-import com.fs.pxe.bpel.o.OBase;
-import com.fs.pxe.bpel.o.OProcess;
-import com.fs.pxe.bpel.o.OScope;
+import org.apache.ode.bpel.o.OBase;
+import org.apache.ode.bpel.o.OProcess;
+import org.apache.ode.bpel.o.OScope;
 
 import java.util.ArrayList;
 import java.util.List;

Modified: incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/bpeldd.xsd
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/bpeldd.xsd?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/bpeldd.xsd (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/bpeldd.xsd Thu Jul 27 14:51:14 2006
@@ -1,7 +1,7 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema"
-           targetNamespace="http://pxe.fivesight.com/schemas/2006/02/14/bpeldd"
-           xmlns:dd="http://pxe.fivesight.com/schemas/2006/02/14/bpeldd"
+           targetNamespace="http://ode.fivesight.com/schemas/2006/02/14/bpeldd"
+           xmlns:dd="http://ode.fivesight.com/schemas/2006/02/14/bpeldd"
            elementFormDefault="qualified">
 
   <xs:element name="deployment-descriptor" id="deployment-descriptor" type="dd:tDeployment-descriptor"/>
@@ -38,7 +38,7 @@
       <xs:element name="process-events" minOccurs="0" maxOccurs="1">
         <xs:annotation>
           <xs:documentation>
-            Defines which events should be generated by PXE (process-level).
+            Defines which events should be generated by ODE (process-level).
           </xs:documentation>
         </xs:annotation>
         <xs:complexType>
@@ -47,7 +47,7 @@
             <xs:element name="scope-events" minOccurs="0" maxOccurs="unbounded">
               <xs:annotation>
                 <xs:documentation>
-                  Defines which events should be generated by PXE (scope-level).
+                  Defines which events should be generated by ODE (scope-level).
                 </xs:documentation>
               </xs:annotation>
               <xs:complexType>

Modified: incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/bpeldd.xsdconfig
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/bpeldd.xsdconfig?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/bpeldd.xsdconfig (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/bpeldd.xsdconfig Thu Jul 27 14:51:14 2006
@@ -1,8 +1,8 @@
 <xb:config xmlns:xb="http://xml.apache.org/xmlbeans/2004/02/xbean/config"
-           xmlns:bpeldd="http://pxe.fivesight.com/schemas/2006/02/14/bpeldd">
+           xmlns:bpeldd="http://ode.fivesight.com/schemas/2006/02/14/bpeldd">
 
-  <xb:namespace uri="http://pxe.fivesight.com/schemas/2006/02/14/bpeldd">
-    <xb:package>com.fs.pxe.bpel.dd</xb:package>
+  <xb:namespace uri="http://ode.fivesight.com/schemas/2006/02/14/bpeldd">
+    <xb:package>org.apache.ode.bpel.dd</xb:package>
   </xb:namespace> 
   
   <xb:namespace uri="##any">

Modified: incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/dd.xsd
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/dd.xsd?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/dd.xsd (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/dd.xsd Thu Jul 27 14:51:14 2006
@@ -1,7 +1,7 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema"
-           targetNamespace="http://pxe.fivesight.com/schemas/2006/06/27/dd"
-           xmlns:dd="http://pxe.fivesight.com/schemas/2006/06/27/dd"
+           targetNamespace="http://ode.fivesight.com/schemas/2006/06/27/dd"
+           xmlns:dd="http://ode.fivesight.com/schemas/2006/06/27/dd"
            elementFormDefault="qualified">
 
   <xs:element name="deploy" id="deploy" type="dd:tDeployment"/>

Modified: incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/dd.xsdconfig
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/dd.xsdconfig?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/dd.xsdconfig (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-dd/src/main/xsd/dd.xsdconfig Thu Jul 27 14:51:14 2006
@@ -1,8 +1,8 @@
 <xb:config xmlns:xb="http://xml.apache.org/xmlbeans/2004/02/xbean/config"
-           xmlns:dd="http://pxe.fivesight.com/schemas/2006/06/27/dd">
+           xmlns:dd="http://ode.fivesight.com/schemas/2006/06/27/dd">
 
-  <xb:namespace uri="http://pxe.fivesight.com/schemas/2006/06/27/dd">
-    <xb:package>com.fs.pxe.bpel.dd2</xb:package>
+  <xb:namespace uri="http://ode.fivesight.com/schemas/2006/06/27/dd">
+    <xb:package>org.apache.ode.bpel.dd2</xb:package>
   </xb:namespace> 
   
   <xb:namespace uri="##any">

Modified: incubator/ode/scratch/pxe-iapi/bpel-el-xpath10/nbproject/project.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-el-xpath10/nbproject/project.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-el-xpath10/nbproject/project.xml (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-el-xpath10/nbproject/project.xml Thu Jul 27 14:51:14 2006
@@ -4,7 +4,7 @@
     <configuration>
         <general-data xmlns="http://www.netbeans.org/ns/freeform-project/1">
             <!--Do not use Project Properties customizer when editing this file manually.-->
-            <name>PXE-bpel-el-xpath10</name>
+            <name>ODE-bpel-el-xpath10</name>
             <properties>
                 <property-file>../build/netbeans-build.properties</property-file>
                 <property-file>../buildlib/netbeans-libs.properties</property-file>
@@ -17,7 +17,7 @@
                     <location>src/java</location>
                 </source-folder>
                 <build-folder>
-                    <location>C:\Data\fivesight\cvs\pxe\install~\int</location>
+                    <location>C:\Data\fivesight\cvs\ode\install~\int</location>
                 </build-folder>
             </folders>
             <ide-actions>

Modified: incubator/ode/scratch/pxe-iapi/bpel-el-xpath10/pom.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-el-xpath10/pom.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-el-xpath10/pom.xml (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-el-xpath10/pom.xml Thu Jul 27 14:51:14 2006
@@ -1,33 +1,33 @@
 <?xml version="1.0"?>
 <project>
-    <groupId>pxe</groupId>
-    <artifactId>pxe-bpel-el-xpath10</artifactId>
-    <name>PXE :: BPEL XPath 1.0</name>
+    <groupId>ode</groupId>
+    <artifactId>ode-bpel-el-xpath10</artifactId>
+    <name>ODE :: BPEL XPath 1.0</name>
     <description>Implementation of the XPath 1.0 expression language.</description>
 
     <modelVersion>4.0.0</modelVersion>
     <parent>
-        <groupId>pxe</groupId>
-        <artifactId>pxe</artifactId>
+        <groupId>ode</groupId>
+        <artifactId>ode</artifactId>
         <version>2.0-SNAPSHOT</version>
     </parent>
     <version>2.0-SNAPSHOT</version>
     <dependencies>
         <dependency>
-            <groupId>pxe</groupId>
-            <artifactId>pxe-bpel-bom</artifactId>
+            <groupId>ode</groupId>
+            <artifactId>ode-bpel-bom</artifactId>
         </dependency>
         <dependency>
-            <groupId>pxe</groupId>
-            <artifactId>pxe-bpel-api</artifactId>
+            <groupId>ode</groupId>
+            <artifactId>ode-bpel-api</artifactId>
         </dependency>
         <dependency>
-            <groupId>pxe</groupId>
-            <artifactId>pxe-bpel-obj</artifactId>
+            <groupId>ode</groupId>
+            <artifactId>ode-bpel-obj</artifactId>
         </dependency>
         <dependency>
-            <groupId>pxe</groupId>
-            <artifactId>pxe-utils</artifactId>
+            <groupId>ode</groupId>
+            <artifactId>ode-utils</artifactId>
         </dependency>
         <dependency>
           <groupId>jaxen</groupId>

Modified: incubator/ode/scratch/pxe-iapi/bpel-el-xpath10/src/main/java/org/apache/ode/bpel/elang/xpath10/compiler/CompilationExceptionWrapper.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-el-xpath10/src/main/java/org/apache/ode/bpel/elang/xpath10/compiler/CompilationExceptionWrapper.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/StaticCheckTCase.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/StaticCheckTCase.java Thu Jul 27 14:51:14 2006
@@ -3,12 +3,12 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler;
+package org.apache.ode.bpel.compiler;
 
-import com.fs.pxe.bom.wsdl.Definition4BPEL;
-import com.fs.pxe.bpel.capi.CompilationException;
-import com.fs.pxe.bpel.capi.CompilationMessage;
-import com.fs.pxe.bpel.capi.CompileListener;
+import org.apache.ode.bom.wsdl.Definition4BPEL;
+import org.apache.ode.bpel.capi.CompilationException;
+import org.apache.ode.bpel.capi.CompilationMessage;
+import org.apache.ode.bpel.capi.CompileListener;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -26,7 +26,7 @@
 
 
 /**
  * JUnit {@link TestCase} of static-analysis checking in the PXE BPEL compiler.
  * These test cases are intended to be run as part of a suite. Each test case
  * instance is used to test a particular detectable error condition.
  */
@@ -26,7 +26,7 @@
 
 /**
- * JUnit {@link TestCase} of static-analysis checking in the PXE BPEL compiler.
+ * JUnit {@link TestCase} of static-analysis checking in the ODE BPEL compiler.
  * These test cases are intended to be run as part of a suite. Each test case
  * instance is used to test a particular detectable error condition.

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/WSDLRegistryTest.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/WSDLRegistryTest.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler_2_0/GoodCompileTCase.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler_2_0/GoodCompileTCase.java Thu Jul 27 14:51:14 2006
@@ -3,12 +3,12 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.compiler_2_0;
+package org.apache.ode.bpel.compiler_2_0;
 
-import com.fs.pxe.bpel.capi.CompilationMessage;
-import com.fs.pxe.bpel.capi.CompileListener;
-import com.fs.pxe.bpel.compiler.BpelC;
-import com.fs.utils.StreamUtils;
+import org.apache.ode.bpel.capi.CompilationMessage;
+import org.apache.ode.bpel.capi.CompileListener;
+import org.apache.ode.bpel.compiler.BpelC;
+import org.apache.ode.utils.StreamUtils;
 
 import java.io.ByteArrayOutputStream;
 import java.net.URL;
@@ -18,7 +18,7 @@
 
 
 /**
  * JUnit {@link TestCase} of the PXE BPEL compiler. This test case provides
  * is not very complex, it simply ensures that the given BPEL input compiles
  * succesfully. These test cases are intended to be run as part of a suite. 
  */
@@ -18,7 +18,7 @@
 
 /**
- * JUnit {@link TestCase} of the PXE BPEL compiler. This test case provides
+ * JUnit {@link TestCase} of the ODE BPEL compiler. This test case provides
  * is not very complex, it simply ensures that the given BPEL input compiles
  * succesfully. These test cases are intended to be run as part of a suite. 

Modified: incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/BpelParseErr.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-compiler/src/test/resources/org/apache/ode/bpel/compiler/BpelParseErr.wsdl?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-el-xpath10/src/main/java/org/apache/ode/bpel/elang/xpath10/compiler/CompilationExceptionWrapper.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-el-xpath10/src/main/java/org/apache/ode/bpel/elang/xpath10/compiler/CompilationExceptionWrapper.java Thu Jul 27 14:51:14 2006
@@ -3,15 +3,15 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.elang.xpath10.compiler;
+package org.apache.ode.bpel.elang.xpath10.compiler;
 
-import com.fs.pxe.bpel.capi.CompilationException;
+import org.apache.ode.bpel.capi.CompilationException;
 
 import org.jaxen.JaxenException;
 
 
 /**
  * Jaxen-compliant wrapper for {@link com.fs.pxe.bpel.capi.CompilationException}.
  */
 class CompilationExceptionWrapper extends JaxenException {
@@ -3,15 +3,15 @@
 
 /**
- * Jaxen-compliant wrapper for {@link com.fs.pxe.bpel.capi.CompilationException}.
+ * Jaxen-compliant wrapper for {@link org.apache.ode.bpel.capi.CompilationException}.
  */
 class CompilationExceptionWrapper extends JaxenException {